import datetime


def get_copyright_years(project_year_started):
    # return ", ".join(map(str, range(int(project_year_started), datetime.datetime.now().year + 1)))
    general_current_year = datetime.datetime.now().year
    if str(general_current_year) == project_year_started:
        return general_current_year
    return f"{project_year_started}-{general_current_year}"



# this is wrong for the tag since they may not be alphabetically ordered...
# tag=subprocess.check_output(['git', 'tag']).decode().rstrip()
# if tag!='':
#    d.git_last_tag=tag.split()[-1].rstrip()
# else:
#    d.git_last_tag='no git tag yet'

# this is right
import subprocess

git_last_tag = subprocess.check_output(
    ["git", "describe", "--abbrev=0", "--tags"], stderr=subprocess.DEVNULL
).decode().rstrip()
git_describe = subprocess.check_output(
    ["git", "describe"], stderr=subprocess.DEVNULL
).decode().rstrip()
git_version = ".".join(git_describe.split("-"))
